==> style-o-matic-1.1.5.tgz: package/es/components/Toasts/ToastMessage.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import _ from "lodash";
import React from "react";
import { CoreComponent, setCorePropDefaults, getValidProps, ROLE } from "../../lib";

var ToastMessage = (_temp = _class = function (_CoreComponent) {
  _inherits(ToastMessage, _CoreComponent);

  function ToastMessage() {
    _classCallCheck(this, ToastMessage);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToastMessage.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      React.createElement(
        "div",
        { className: "ui-toasts-toast-icon" },
        "\uD83D\uDD6D"
      ),
      React.createElement(
        "div",
        { className: "ui-toasts-toast-msg" },
        children
      ),
      React.createElement(
        "div",
        {
          className: "ui-toasts-toast-close",
          role: "presentation",
          onClick: this.props.onClick
        },
        "\u2715"
      )
    );
  };

  return ToastMessage;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TOAST
}), _temp);


export default ToastMessage;

==> style-o-matic-1.1.37.tgz: package/es/components/Toasts/ToastMessage.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import _ from "lodash";
import React from "react";
import { CoreComponent, getCorePropDefaults, getValidProps, ROLE } from "../../lib";

var ToastMessage = (_temp = _class = function (_CoreComponent) {
  _inherits(ToastMessage, _CoreComponent);

  function ToastMessage() {
    _classCallCheck(this, ToastMessage);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToastMessage.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      React.createElement(
        "div",
        { className: "ui-toasts-toast-icon" },
        "\uD83D\uDD6D"
      ),
      React.createElement(
        "div",
        { className: "ui-toasts-toast-msg" },
        children
      ),
      React.createElement(
        "div",
        {
          className: "ui-toasts-toast-close",
          role: "presentation",
          onClick: this.props.onClick
        },
        "\u2715"
      )
    );
  };

  return ToastMessage;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TOAST
}), _temp);


export default ToastMessage;
